/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ProjectFactory;
import org.netbeans.spi.project.ProjectState;
import org.openide.filesystems.FileObject;
import org.openide.util.Exceptions;

/**
 *
 * @author Timon Veenstra
 */
@org.openide.util.lookup.ServiceProvider(service = ProjectFactory.class)
public class FarmProjectFactory implements ProjectFactory {

    public static final String ICON = "nl/cloudfarming/client/farm/house.png";
    public static final String FARM_FILE = "farm.bin";

    //Specifies when a project is a project, i.e.,
    //if the project directory "texts" is present:
    @Override
    public boolean isProject(FileObject projectDirectory) {
        return projectDirectory.getFileObject(FARM_FILE) != null;
    }

    //Specifies when the project will be opened, i.e.,
    //if the project exists:
    @Override
    public Project loadProject(FileObject dir, ProjectState state) throws IOException {
        FarmProject project = null;
        if (isProject(dir)) {
            try (ObjectInputStream ois = new ObjectInputStream(dir.getFileObject(FARM_FILE).getInputStream())) {
                Farm farm = (Farm) ois.readObject();
                project = new FarmProject(dir, state, farm);
            } catch (ClassNotFoundException ex) {
                Exceptions.printStackTrace(ex);
            }
        }
        return project;
    }

    @Override
    public void saveProject(final Project project) throws IOException, ClassCastException {
        FileObject projectRoot = project.getProjectDirectory();

        try (ObjectOutputStream oos = new ObjectOutputStream(projectRoot.createAndOpen(FARM_FILE))) {
            oos.writeObject(((FarmProject) project).getFarm());
        }


    }
}
