/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.farm;

import java.io.IOException;
import java.util.Collections;
import java.util.HashSet;
import java.util.Set;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.fieldplan.FieldPlanProject;
import org.netbeans.api.project.Project;
import org.netbeans.api.project.ProjectManager;
import org.netbeans.spi.project.SubprojectProvider;
import org.openide.filesystems.FileObject;

/**
 *
 * @author Timon Veenstra
 */
public class FarmSubProjectProvider implements SubprojectProvider {

    private final FarmProject project;
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.farm");

    FarmSubProjectProvider(FarmProject project) {
        this.project = project;
    }

    @Override
    public Set<? extends Project> getSubprojects() {
        return loadProjects(project.getProjectDirectory());
    }

    private Set loadProjects(FileObject dir) {
        Set newProjects = new HashSet();
        try {
            FileObject[] subFolders = dir.getChildren(); //subfolders of root folder
            for (FileObject subFolder : subFolders) {
                LOG.log(Level.FINEST, "found child of root: {0}", subFolder.getName());
                if (subFolder.isFolder()) {
                    Project subp = ProjectManager.getDefault().findProject(subFolder);
                    if (subp != null) {
                        newProjects.add(subp);
                    }
                }
            }
        } catch (IOException e) {
        }
        return Collections.unmodifiableSet(newProjects);
    }

    @Override
    public final void addChangeListener(ChangeListener l) {
    }

    @Override
    public final void removeChangeListener(ChangeListener l) {
    }
}
